#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pymeili.beautifyplot import (
    initplot,
    colorlist,
    cmaplist,
    getBARHNO,
    getBARNO,
    getHISTNO,
    getPLOTNO,
    getSCATTERNO,
    savefig,
    title, lefttitle, righttitle,
    scatter, plot, bar, hist, hist2d, pie, barh, table,
    contour, contourf, colorbar,
    xlabel, ylabel, xticks, yticks, xyticks, ticksall,
    xlim, ylim, xylim, xscale, yscale, xlog, ylog,
    grid, spines, legend, hidespines, xaxisposition, yaxisposition,
    axhline, axvline, text, annotate, labeltext,
    fill_between, fill_betweenx,
    figsize, show, clf, close, figure,
    imread, imshow, imsave,
    
)

__version__: str = '0.1.1'
